@@ -1,13 +1,13 @@
-use poem::{get, handler, route, web::Path, Server};
+use poem::{get, route, web::Path, Server};
 
-#[handler]
+#[get]
 fn hello(Path(name): Path<String>) -> String {
     format!("hello: {}", name)
 }
 
 #[tokio::main]
 async fn main() {
-    let app = route().at("/hello/:name", get(hello));
+    let app = route().at("/hello/:name", hello);
     let server = Server::bind("127.0.0.1:3000").await.unwrap();
     server.run(app).await.unwrap();
 }
